# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Please add your functional changes to the appropriate section in the PR.
Keep it human-readable, your future self will thank you!

## [Unreleased]

### Added

### Changed

### Removed

## [0.3.0] - Initial Release, utility functions

### Added
- Command line interface utility

## [0.2.0] - Initial Release, utility functions

### Changed
- updated documentation

## [0.1.0] - Initial Release, utility functions

### Added
- Documentation
- Initial implementation for a series of utility functions for used by the rest of the Anemoi packages

<!-- Add Git Diffs for Links above -->
[unreleased]: https://github.com/ecmwf/anemoi-utils/compare/0.3.13...HEAD
https://github.com/ecmwf/anemoi-utils/compare/0.2.0...0.3.0
https://github.com/ecmwf/anemoi-utils/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/ecmwf/anemoi-utils/releases/tag/0.1.0
